/*
*******************************************************************************
**
**  This device driver was created by Applilet2 for 78K0/Kx2
**  8-Bit Single-Chip Microcontrollers
**
**  Copyright(C) NEC Electronics Corporation 2002 - 2008
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	Timer.c
**  Abstract :	This file implements device driver for Timer module.
**  APIlib :	Applilet2 for 78K0/Kx2 V2.10 [6 Mar. 2007]
**
**  Device :	uPD78F0515_48
**
**  Compiler :	CC78K0
**
**  Creation date:	2008/04/27
**  
*******************************************************************************
*/

/*
*******************************************************************************
** Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "Timer.h"
/* Start user code for include definition. Do not edit comment generated here */
/* End user code for include definition. Do not edit comment generated here */
#include "user_define.h"

/*
*******************************************************************************
**  Global define
*******************************************************************************
*/
/* Start user code for global definition. Do not edit comment generated here */
/* End user code for global definition. Do not edit comment generated here */


/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initiate TM00.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Init()
{
	TMC00 = TM0_OPERATE_DISABLE;
	TMMK000 = 1;			/* INTTM000 disabled */
	TMIF000 = 0;			/* INTTM000 interrupt flag clear */
	TMMK010 = 1;			/* INTTM010 disabled */
	TMIF010 = 0;			/* INTTM010 interrupt flag clear */
	TMPR000 = 1;			/* set INTTM000 low priority */
	PRM00 = TM0_PRM0_INITIALVALUE | TM0_TI00_VALID_EDGE_RISE | TM0_EXTER_CLOCK;
	/* TM00 external event counter */
	CRC00 = TM0_CRC0_INITIALVALUE | TM0_CR00_COMPARE;
	TOC00 = TM0_TOC0_INITIALVALUE;
	CR000 = TM0_CR000_VALUE;
	CR010 = TM0_CR010_VALUE;
	/* TI000(P00) input */
	PM0 |= 0x01;
	ISC &= ~0x02;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function start TM00 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Start()
{
	TMMK000 = 0;			/* INTTM000 enabled */
	TMC00 &= (UCHAR)~TM0_OPERATE;
	TMC00 |= TM0_CLEAR_BY_MATCH_CR00;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function stop TM00 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Stop( void )
{
	TMC00 = TM0_OPERATE_DISABLE;
 
	TMMK000 = 1;			/* INTTM000 disabled */
	TMIF000 = 0;			/* INTTM000 interrupt flag clear */
 
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function change TM00 interval value.
**
**  Parameters:
**	*array_reg:	array_reg values in the compare registers
**	array_num:	value number
**
**  Returns:
**	MD_OK
**	MD_ERROR
**
**-----------------------------------------------------------------------------
*/
MD_STATUS TM00_ChangeTimerCondition( USHORT* array_reg, USHORT array_num )
{
	switch (array_num){
		case 1:
			 CR000 = array_reg[0];
			 break;			 
		case 2:
			CR000 = array_reg[0];
			CR010 = array_reg[1];
			break;
		default:
			return MD_ERROR;
	}
	return MD_OK;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initiate TM50.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM50_Init()
{
	TCE50 = 0;			/* TM50 counter disable */
	TMMK50	= 1;		/* INTTM50 interrupt disabled */
	TMIF50	= 0;		/* clear interrupt flag */
	TMPR50	= 0;		/* set high priority level */

	TCL50 = TM5_INTER_CLOCK_6;

	 /* TM50 interval mode */
	CR50 = TM50_COMPARE_VALUE;  
	TMC50 = TM5_TMC5_INITIALVALUE | TM5_OPT_MODE_OTHER | TM5_OUTPUT_FF_ENABLE;	
 
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function start TM50 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM50_Start()
{
	TMMK50	= 0;		/* INTTM50 interrupt enabled */
	TCE50 = 1;			/* count operation start */
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function stop TM50 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM50_Stop()
{
	TCE50 = 0;			/* TM50 counter disable */
	TMMK50	= 1;		/* INTTM50 interrupt disabled */
	TMIF50	= 0;		/* clear interrupt flag */
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function change TM50 compare value.
**
**  Parameters:
**	value:	 value for compare register
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM50_ChangeTimerCondition(UCHAR value)
{
	CR50 = value;
}

/* Start adding user code. Do not edit comment generated here */
/* End user code adding. Do not edit comment generated here */


